This template shows off a simple CRUD App, which allows you to create,
read, update, and delete menu items.

## Lessons 🎓

In this example you can see:

- How to populate your application with your own data, add new items, edit
  existing items, and delete items. The data is stored in the `menu_items` state
  of the `CrudPage` component.
- How to to create and use `custom dialogs`.

## Components 🧩

The example consists of one main component:

`CrudPage`: Displays the list of menu items and allows the user to add new
items, delete existing items, select an item for editing or create an new one.
